==> navigation_plus-1.0.1.tar.gz: navigation_plus/js/edit-mode-plugin.js <==
(($, Drupal, once, displace) => {

  Drupal.behaviors.NavigationPlusEditMode = {
    attach: (context, settings) => {

      once('NavigationPlusEditMode', 'body', context).forEach(body => {
        if (Drupal.NavigationPlus.isInitialView()) {
          const mode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          Drupal.behaviors.NavigationPlusModes.EnableMode(mode);
        } else if (Drupal.NavigationPlus.getCookieValue('navigationMode') === 'edit') {
          // Enable active tools on page load.
          Drupal.NavigationPlus.ModeManager.getPlugin('edit').activateTool();
        }
      });

      once('NavigationPlusEditMode', '#navigation-plus-edit .navigation-plus-button', context).forEach(toolButton => {
        // Listen for tool activation clicks.
        toolButton.addEventListener('click', (event) => {
          const activeTool = localStorage.getItem('navigation_plus.tool.active') ?? 'pointer';
          const nextTool = event.currentTarget.dataset.tool;

          Drupal.NavigationPlus.ToolManager.getPlugin(activeTool).disable().then(() => {
            Drupal.NavigationPlus.ModeManager.getPlugin('edit').activateTool(nextTool);
          });
        });
      });
    }
  };

  /**
   * Navigation + Edit Mode plugin
   */
  class EditModePlugin extends Drupal.NavigationPlus.ModePluginBase {
    id = 'edit';
    enable = () => {
      this.ReloadPageElements().then((response, status) => {
        this.activateTool();
      }).catch((error) => {
        console.error('An error occurred while trying to load the editing UI:', error);
      });
    };
    disable = (editModeDisabled = false) => {
      this.removeMouse();
      const activeTool = localStorage.getItem('navigation_plus.tool.active');
      Drupal.NavigationPlus.ToolManager.getPlugin(activeTool).disable(true);
      return this.ReloadPageElements();
    };
    removeMouse = () => {
      document.querySelectorAll('.navigation-plus-button.active').forEach(button => {
        document.querySelector('html').classList.remove(button.dataset.tool);
        button.classList.remove('active');
      });
    };
    changeMouse = (pluginId) => {
      this.removeMouse();
      document.querySelector('[data-tool="' + pluginId + '"]').classList.add('active');
      document.querySelector('html').classList.add(pluginId);
      sessionStorage.setItem('mouseState', pluginId);
    };
    activateTool = (toolPluginId = null) => {
      const isInitialPageEdit = Drupal.NavigationPlus.isInitialView();

      if (!toolPluginId) {
        const defaultTool = drupalSettings.navigationPlus.defaultTool ?? 'pointer';
        if (isInitialPageEdit) {
          // Use the configured tool for this content type when initially editing
          // a page.
          toolPluginId = defaultTool;
        } else {
          // Ensure the active tool is till valid for this entity type.
          let activeToolId = localStorage.getItem('navigation_plus.tool.active');
          try {
            Drupal.NavigationPlus.ToolManager.getPlugin(activeToolId);
          } catch (e) {
            activeToolId = null;
          }
          toolPluginId = activeToolId ?? defaultTool;
        }
      }

      this.changeMouse(toolPluginId);
      const tool = Drupal.NavigationPlus.ToolManager.getPlugin(toolPluginId);
      tool.enable().then(() => {
        if (isInitialPageEdit) {
          tool.initialEdit();
          // Keep track if we have edited this page before.
          const storedPages = sessionStorage.getItem('navigationPlus.EditedPages');
          let editedPages = storedPages ? JSON.parse(storedPages) : [];
          editedPages.push(window.location.pathname);
          sessionStorage.setItem('navigationPlus.EditedPages', JSON.stringify(editedPages));
        }
        localStorage.setItem('navigation_plus.tool.active', toolPluginId);
        document.cookie = 'activeTool=' + toolPluginId + '; path=/';
      });
    };

    /**
     * Reload page elements.
     *
     * When the edit cookie changes, AJAX reload the page so that the page
     * elements will have the UI attributes applied to them.
     */
    ReloadPageElements = () => {
      return new Promise((resolve, reject) => {
        const wrapper = this.getMainEntityWrapper();
        if (!wrapper) {
          return;
        }
        const parts = wrapper.dataset.navigationPlusEntityWrapper.split('::');

        let ajax = Drupal.NavigationPlus.ModePluginBase.ajax({
          url: Drupal.url('navigation-plus/load-editable-page/' + parts[0] + '/' + parts[1] + '/' + wrapper.dataset.navigationPlusViewMode),
          type: 'POST',
          dataType: 'text',
          progress: {
            type: 'fullscreen',
            message: Drupal.t('Loading Layout Builder...'),
          },
          error: error => {
            document.querySelectorAll('.ajax-progress').forEach(progress => {
              progress.remove();
            });
            console.info('Failed to load the editing UI for ' + wrapper.dataset.navigationPlusEntityWrapper);
            console.info(error.responseText);
          },
          success: (response, status) => {
            Promise.resolve(
              Drupal.Ajax.prototype.success.call(ajax, response, status),
            ).then(() => {
              resolve();
            });
          },
        });
        ajax.execute();
      });
    };

    getMainEntityWrapper = () => {
      return document.querySelector('.navigation-plus-entity-wrapper[data-main-entity]');
    };

  }
  Drupal.NavigationPlus.ModeManager.registerPlugin(new EditModePlugin());
})(jQuery, Drupal, once, Drupal.displace);

==> navigation_plus-1.0.10.tar.gz: navigation_plus/js/edit-mode-plugin.js <==
(($, Drupal, once, displace) => {

  Drupal.behaviors.NavigationPlusEditMode = {
    attach: (context, settings) => {

      once('NavigationPlusEditMode', 'body', context).forEach(body => {
        if (Drupal.NavigationPlus.contentWasJustCreated()) {
          const mode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          Drupal.behaviors.NavigationPlusModes.EnableMode(mode);
        } else if (Drupal.NavigationPlus.getCookieValue('navigationMode') === 'edit') {
          // Enable active tools on page load.
          Drupal.NavigationPlus.ModeManager.getPlugin('edit').activateTool();
        }
      });

      once('NavigationPlusEditMode', '#navigation-plus-edit .navigation-plus-button', context).forEach(toolButton => {
        // Listen for tool activation clicks.
        toolButton.addEventListener('click', (event) => {
          const activeTool = localStorage.getItem('navigation_plus.tool.active') ?? 'pointer';
          const nextTool = event.currentTarget.dataset.tool;

          Drupal.NavigationPlus.ToolManager.getPlugin(activeTool).disable().then(() => {
            Drupal.NavigationPlus.ModeManager.getPlugin('edit').activateTool(nextTool);
          });
        });
      });
    }
  };

  /**
   * Navigation + Edit Mode plugin
   */
  class EditModePlugin extends Drupal.NavigationPlus.ModePluginBase {
    id = 'edit';
    enable = () => {
      this.ReloadPageElements().then((response, status) => {
        this.activateTool();
      }).catch((error) => {
        console.error('An error occurred while trying to load the editing UI:', error);
      });
    };
    disable = (editModeDisabled = false) => {
      this.removeMouse();
      const activeTool = localStorage.getItem('navigation_plus.tool.active');
      Drupal.NavigationPlus.ToolManager.getPlugin(activeTool).disable(true);
      return this.ReloadPageElements();
    };
    removeMouse = () => {
      document.querySelectorAll('.navigation-plus-button.active').forEach(button => {
        document.querySelector('html').classList.remove(button.dataset.tool);
        button.classList.remove('active');
      });
    };
    changeMouse = (pluginId) => {
      this.removeMouse();
      document.querySelector('[data-tool="' + pluginId + '"]').classList.add('active');
      document.querySelector('html').classList.add(pluginId);
      sessionStorage.setItem('mouseState', pluginId);
    };
    activateTool = (toolPluginId = null) => {
      const isInitialPageEdit = Drupal.NavigationPlus.contentWasJustCreated();

      if (!toolPluginId) {
        const defaultTool = drupalSettings.navigationPlus.defaultTool ?? 'pointer';
        if (isInitialPageEdit) {
          // Use the configured tool for this content type when initially editing
          // a page.
          toolPluginId = defaultTool;
        } else {
          // Ensure the active tool is till valid for this entity type.
          let activeToolId = localStorage.getItem('navigation_plus.tool.active');
          try {
            Drupal.NavigationPlus.ToolManager.getPlugin(activeToolId);
          } catch (e) {
            activeToolId = null;
          }
          toolPluginId = activeToolId ?? defaultTool;
        }
      }

      this.changeMouse(toolPluginId);
      const tool = Drupal.NavigationPlus.ToolManager.getPlugin(toolPluginId);
      tool.enable().then(() => {
        if (isInitialPageEdit) {
          tool.initialEdit();
        }
        localStorage.setItem('navigation_plus.tool.active', toolPluginId);
        document.cookie = 'activeTool=' + toolPluginId + '; path=/';
      });
    };

    /**
     * Reload page elements.
     *
     * When the edit cookie changes, AJAX reload the page so that the page
     * elements will have the UI attributes applied to them.
     */
    ReloadPageElements = () => {
      return new Promise((resolve, reject) => {
        const wrapper = this.getMainEntityWrapper();
        if (!wrapper) {
          return;
        }
        const parts = wrapper.dataset.navigationPlusEntityWrapper.split('::');

        let ajax = Drupal.NavigationPlus.ModePluginBase.ajax({
          url: Drupal.url('navigation-plus/load-editable-page/' + parts[0] + '/' + parts[1] + '/' + wrapper.dataset.navigationPlusViewMode),
          type: 'POST',
          dataType: 'text',
          progress: {
            type: 'fullscreen',
            message: Drupal.t('Loading Layout Builder...'),
          },
          error: error => {
            document.querySelectorAll('.ajax-progress').forEach(progress => {
              progress.remove();
            });
            console.info('Failed to load the editing UI for ' + wrapper.dataset.navigationPlusEntityWrapper);
            console.info(error.responseText);
          },
          success: (response, status) => {
            Promise.resolve(
              Drupal.Ajax.prototype.success.call(ajax, response, status),
            ).then(() => {
              resolve();
            });
          },
        });
        ajax.execute();
      });
    };

    getMainEntityWrapper = () => {
      return document.querySelector('.navigation-plus-entity-wrapper[data-main-entity]');
    };

  }
  Drupal.NavigationPlus.ModeManager.registerPlugin(new EditModePlugin());
})(jQuery, Drupal, once, Drupal.displace);
